/* installer-media.c generated by valac 0.32.0.73-ab1d1, the Vala compiler
 * generated from installer-media.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <osinfo/osinfo.h>
#include <gudev/gudev.h>
#include <glib/gi18n-lib.h>
#include <stdio.h>


#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;
typedef struct _BoxesInstallerMediaNewForPathData BoxesInstallerMediaNewForPathData;
typedef struct _BoxesInstallerMediaPrepareData BoxesInstallerMediaPrepareData;
typedef struct _BoxesInstallerMediaPrepareForInstallationData BoxesInstallerMediaPrepareForInstallationData;
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))

#define BOXES_TYPE_CPU_ARCH_COMPATIBILITY (boxes_cpu_arch_compatibility_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesInstallerMediaGetDeviceFromPathData BoxesInstallerMediaGetDeviceFromPathData;
typedef struct _BoxesInstallerMediaGetMediaInfoFromDeviceData BoxesInstallerMediaGetMediaInfoFromDeviceData;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesInstallerMediaNewForPathData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GType object_type;
	BoxesInstallerMedia* self;
	gchar* path;
	BoxesMediaManager* media_manager;
	GCancellable* cancellable;
	GUdevDevice* device;
	const gchar* _tmp0_;
	BoxesMediaManager* _tmp1_;
	GUdevClient* _tmp2_;
	GUdevClient* _tmp3_;
	GCancellable* _tmp4_;
	GUdevDevice* _tmp5_;
	GUdevDevice* _tmp6_;
	GUdevDevice* _tmp7_;
	BoxesMediaManager* _tmp8_;
	BoxesOSDatabase* _tmp9_;
	BoxesOSDatabase* _tmp10_;
	OsinfoMedia* _tmp11_;
	BoxesMediaManager* _tmp12_;
	BoxesOSDatabase* _tmp13_;
	BoxesOSDatabase* _tmp14_;
	const gchar* _tmp15_;
	GCancellable* _tmp16_;
	OsinfoMedia* _tmp17_;
	OsinfoMedia* _tmp18_;
	OsinfoMedia* _tmp19_;
	OsinfoMedia* _tmp20_;
	OsinfoOs* _tmp21_;
	OsinfoOs* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* architecture;
	gchar* _tmp27_;
	BoxesMediaManager* _tmp28_;
	BoxesOSDatabase* _tmp29_;
	BoxesOSDatabase* _tmp30_;
	OsinfoOs* _tmp31_;
	const gchar* _tmp32_;
	OsinfoResources* _tmp33_;
	gint64 _tmp34_;
	gboolean _tmp35_;
	const gchar* _tmp36_;
	const gchar* _tmp37_;
	OsinfoResources* _tmp38_;
	gint64 _tmp39_;
	gint64 _tmp40_;
	gint64 _tmp41_;
	OsinfoResources* _tmp42_;
	gint64 _tmp43_;
	gint64 _tmp44_;
	gint64 _tmp45_;
	OsinfoResources* _tmp46_;
	GError * _inner_error_;
};

struct _BoxesInstallerMediaPrepareData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesInstallerMedia* self;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	gboolean result;
};

struct _BoxesInstallerMediaPrepareForInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesInstallerMedia* self;
	gchar* vm_name;
	GCancellable* cancellable;
};

typedef enum  {
	BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE = -1,
	BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL = 0,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE = 1,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE = 2
} BoxesCPUArchCompatibility;

struct _BoxesInstallerMediaGetDeviceFromPathData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesInstallerMedia* self;
	gchar* path;
	GUdevClient* client;
	GCancellable* cancellable;
	GUdevDevice* result;
	GFile* mount_dir;
	const gchar* _tmp0_;
	GFile* _tmp1_;
	GMount* mount;
	GCancellable* _tmp2_;
	GMount* _tmp3_;
	GFile* root_dir;
	GFile* _tmp4_;
	GFile* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gboolean _tmp10_;
	GVolume* volume;
	GVolume* _tmp11_;
	GVolume* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
	GError* _error_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	GUdevClient* _tmp20_;
	const gchar* _tmp21_;
	GUdevDevice* _tmp22_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesInstallerMediaGetMediaInfoFromDeviceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesInstallerMedia* self;
	GUdevDevice* device;
	BoxesOSDatabase* os_db;
	gboolean _tmp0_;
	GUdevDevice* _tmp1_;
	const gchar* _tmp2_;
	GUdevDevice* _tmp3_;
	gboolean _tmp4_;
	const gchar* _tmp5_;
	GError* _tmp6_;
	GUdevDevice* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	GUdevDevice* _tmp10_;
	const gchar* _tmp11_;
	GUdevDevice* _tmp12_;
	const gchar* _tmp13_;
	gchar* os_id;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	OsinfoOs* _tmp16_;
	BoxesOSDatabase* _tmp17_;
	const gchar* _tmp18_;
	OsinfoOs* _tmp19_;
	OsinfoOs* _tmp20_;
	gchar* media_id;
	GUdevDevice* _tmp21_;
	const gchar* _tmp22_;
	gchar* _tmp23_;
	const gchar* _tmp24_;
	OsinfoMedia* _tmp25_;
	BoxesOSDatabase* _tmp26_;
	OsinfoOs* _tmp27_;
	const gchar* _tmp28_;
	OsinfoMedia* _tmp29_;
	OsinfoMedia* _tmp30_;
	OsinfoMedia* media;
	const gchar* _tmp31_;
	OsinfoMedia* _tmp32_;
	OsinfoMedia* _tmp33_;
	const gchar* _tmp34_;
	GUdevDevice* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	gchar** _tmp39_;
	gchar** _tmp40_;
	gint _tmp40__length1;
	gchar* _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar** _tmp44_;
	gchar** _tmp45_;
	gint _tmp45__length1;
	OsinfoMedia* _tmp46_;
	OsinfoMedia* _tmp47_;
	BoxesOSDatabase* _tmp48_;
	OsinfoMedia* _tmp49_;
	OsinfoMedia* _tmp50_;
	OsinfoMedia* _tmp51_;
	OsinfoMedia* _tmp52_;
	OsinfoMedia* _tmp53_;
	OsinfoOs* _tmp54_;
	OsinfoOs* _tmp55_;
	GError * _inner_error_;
};


static gpointer boxes_installer_media_parent_class = NULL;

GType boxes_installer_media_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_INSTALLER_MEDIA_DUMMY_PROPERTY,
	BOXES_INSTALLER_MEDIA_SUPPORTED_DEVICES,
	BOXES_INSTALLER_MEDIA_INSTALLED_SIZE,
	BOXES_INSTALLER_MEDIA_NEED_USER_INPUT_FOR_VM_CREATION,
	BOXES_INSTALLER_MEDIA_READY_TO_CREATE,
	BOXES_INSTALLER_MEDIA_SUPPORTS_VIRTIO_DISK,
	BOXES_INSTALLER_MEDIA_SUPPORTS_VIRTIO_NET,
	BOXES_INSTALLER_MEDIA_LIVE,
	BOXES_INSTALLER_MEDIA_ARCHITECTURE
};
BoxesInstallerMedia* boxes_installer_media_new_from_iso_info (const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
BoxesInstallerMedia* boxes_installer_media_construct_from_iso_info (GType object_type, const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
void boxes_installer_media_label_setup (BoxesInstallerMedia* self, const gchar* label);
static void boxes_installer_media_construct_for_path_data_free (gpointer _data);
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
void boxes_installer_media_new_for_path (const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_new_for_path_finish (GAsyncResult* _res_, GError** error);
void boxes_installer_media_construct_for_path (GType object_type, const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_construct_for_path_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_installer_media_construct_for_path_co (BoxesInstallerMediaNewForPathData* _data_);
static void boxes_installer_media_get_device_from_path (BoxesInstallerMedia* self, const gchar* path, GUdevClient* client, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GUdevDevice* boxes_installer_media_get_device_from_path_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
GUdevClient* boxes_media_manager_get_client (BoxesMediaManager* self);
static void boxes_installer_media_new_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
static void boxes_installer_media_get_media_info_from_device (BoxesInstallerMedia* self, GUdevDevice* device, BoxesOSDatabase* os_db, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_installer_media_get_media_info_from_device_finish (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_guess_os_from_install_media_path (BoxesOSDatabase* self, const gchar* media_path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
OsinfoMedia* boxes_os_database_guess_os_from_install_media_path_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
gchar* boxes_installer_media_get_architecture (BoxesInstallerMedia* self);
OsinfoResources* boxes_os_database_get_resources_for_os (BoxesOSDatabase* self, OsinfoOs* os, const gchar* architecture);
void boxes_installer_media_set_direct_boot_params (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
static void boxes_installer_media_real_set_direct_boot_params (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
static void boxes_installer_media_real_prepare_data_free (gpointer _data);
static void boxes_installer_media_real_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_installer_media_prepare_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
static gboolean boxes_installer_media_real_prepare_co (BoxesInstallerMediaPrepareData* _data_);
static void boxes_installer_media_real_prepare_for_installation_data_free (gpointer _data);
static void boxes_installer_media_real_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
static gboolean boxes_installer_media_real_prepare_for_installation_co (BoxesInstallerMediaPrepareForInstallationData* _data_);
void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
static void boxes_installer_media_real_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
void boxes_installer_media_clean_up (BoxesInstallerMedia* self);
static void boxes_installer_media_real_clean_up (BoxesInstallerMedia* self);
void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self);
static void boxes_installer_media_real_clean_up_preparation_cache (BoxesInstallerMedia* self);
void boxes_installer_media_setup_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
static void boxes_installer_media_real_setup_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
void boxes_installer_media_add_cd_config (BoxesInstallerMedia* self, GVirConfigDomain* domain, GVirConfigDomainDiskType type, const gchar* iso_path, const gchar* device_name, gboolean mandatory);
void boxes_installer_media_setup_post_install_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
static void boxes_installer_media_real_setup_post_install_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain);
static void boxes_installer_media_eject_cdrom_media (BoxesInstallerMedia* self, GVirConfigDomain* domain);
void boxes_installer_media_populate_setup_box (BoxesInstallerMedia* self, GtkBox* setup_box);
static void boxes_installer_media_real_populate_setup_box (BoxesInstallerMedia* self, GtkBox* setup_box);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
static GList* boxes_installer_media_real_get_vm_properties (BoxesInstallerMedia* self);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
gboolean boxes_installer_media_is_architecture_compatible (BoxesInstallerMedia* self, const gchar* architecture);
GType boxes_cpu_arch_compatibility_get_type (void) G_GNUC_CONST;
BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2);
BoxesVMCreator* boxes_installer_media_get_vm_creator (BoxesInstallerMedia* self);
static BoxesVMCreator* boxes_installer_media_real_get_vm_creator (BoxesInstallerMedia* self);
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
static void boxes_installer_media_get_device_from_path_data_free (gpointer _data);
static gboolean boxes_installer_media_get_device_from_path_co (BoxesInstallerMediaGetDeviceFromPathData* _data_);
static void boxes_installer_media_get_device_from_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_installer_media_get_media_info_from_device_data_free (gpointer _data);
static gboolean boxes_installer_media_get_media_info_from_device_co (BoxesInstallerMediaGetMediaInfoFromDeviceData* _data_);
GQuark boxes_os_database_error_quark (void);
static gchar* boxes_installer_media_get_decoded_udev_property (BoxesInstallerMedia* self, GUdevDevice* device, const gchar* property_name);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void boxes_installer_media_get_media_info_from_device_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
OsinfoMedia* boxes_os_database_get_media_by_id (BoxesOSDatabase* self, OsinfoOs* os, const gchar* id, GError** error);
static void boxes_installer_media_get_decoded_udev_properties_for_media (BoxesInstallerMedia* self, GUdevDevice* device, gchar** udev_props, int udev_props_length1, gchar** media_props, int media_props_length1, OsinfoMedia* media);
void boxes_os_database_guess_os_from_install_media (BoxesOSDatabase* self, OsinfoMedia* media, GAsyncReadyCallback _callback_, gpointer _user_data_);
OsinfoMedia* boxes_os_database_guess_os_from_install_media_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
BoxesInstallerMedia* boxes_installer_media_new (void);
BoxesInstallerMedia* boxes_installer_media_construct (GType object_type);
OsinfoDeviceList* boxes_installer_media_get_supported_devices (BoxesInstallerMedia* self);
guint64 boxes_installer_media_get_installed_size (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_supports_virtio_disk (BoxesInstallerMedia* self);
OsinfoDevice* boxes_find_device_by_prop (OsinfoDeviceList* devices, const gchar* prop_name, const gchar* prop_value);
gboolean boxes_installer_media_get_supports_virtio_net (BoxesInstallerMedia* self);
static void boxes_installer_media_finalize (GObject* obj);
static void _vala_boxes_installer_media_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return self ? g_object_ref (self) : NULL;
#line 435 "installer-media.c"
}


BoxesInstallerMedia* boxes_installer_media_construct_from_iso_info (GType object_type, const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources) {
	BoxesInstallerMedia * self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	OsinfoOs* _tmp2_ = NULL;
	OsinfoOs* _tmp3_ = NULL;
	OsinfoMedia* _tmp4_ = NULL;
	OsinfoMedia* _tmp5_ = NULL;
	OsinfoResources* _tmp6_ = NULL;
	OsinfoResources* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (resources != NULL, NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = (BoxesInstallerMedia*) g_object_new (object_type, NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = path;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (self->device_file);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self->device_file = _tmp1_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = os;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (self->os);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self->os = _tmp3_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = media;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (self->os_media);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self->os_media = _tmp5_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp6_ = resources;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (self->resources);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self->resources = _tmp7_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self->from_image = TRUE;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp8_ = label;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_label_setup (self, _tmp8_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return self;
#line 498 "installer-media.c"
}


BoxesInstallerMedia* boxes_installer_media_new_from_iso_info (const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return boxes_installer_media_construct_from_iso_info (BOXES_TYPE_INSTALLER_MEDIA, path, label, os, media, resources);
#line 505 "installer-media.c"
}


static void boxes_installer_media_construct_for_path_data_free (gpointer _data) {
	BoxesInstallerMediaNewForPathData* _data_;
	_data_ = _data;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->path);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->media_manager);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->self);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_slice_free (BoxesInstallerMediaNewForPathData, _data_);
#line 522 "installer-media.c"
}


void boxes_installer_media_construct_for_path (GType object_type, const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesInstallerMediaNewForPathData* _data_;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	BoxesMediaManager* _tmp2_ = NULL;
	BoxesMediaManager* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
	GCancellable* _tmp5_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_slice_new0 (BoxesInstallerMediaNewForPathData);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_installer_media_construct_for_path);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_installer_media_construct_for_path_data_free);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->object_type = object_type;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = path;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->path);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->path = _tmp1_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = media_manager;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->media_manager);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->media_manager = _tmp3_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = cancellable;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->cancellable = _tmp5_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_construct_for_path_co (_data_);
#line 568 "installer-media.c"
}


BoxesInstallerMedia* boxes_installer_media_construct_for_path_finish (GAsyncResult* _res_, GError** error) {
	BoxesInstallerMedia* result;
	BoxesInstallerMediaNewForPathData* _data_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return;
#line 579 "installer-media.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _data_->self;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 589 "installer-media.c"
}


static void boxes_installer_media_new_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesInstallerMediaNewForPathData* _data_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = _user_data_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_source_object_ = source_object;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_res_ = _res_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_construct_for_path_co (_data_);
#line 603 "installer-media.c"
}


static gboolean boxes_installer_media_construct_for_path_co (BoxesInstallerMediaNewForPathData* _data_) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	switch (_data_->_state_) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 0:
#line 612 "installer-media.c"
		goto _state_0;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 1:
#line 616 "installer-media.c"
		goto _state_1;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 2:
#line 620 "installer-media.c"
		goto _state_2;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 3:
#line 624 "installer-media.c"
		goto _state_3;
		default:
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_assert_not_reached ();
#line 629 "installer-media.c"
	}
	_state_0:
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self = (BoxesInstallerMedia*) g_object_new (_data_->object_type, NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp0_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp0_ = _data_->path;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp1_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp1_ = _data_->media_manager;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp2_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp2_ = boxes_media_manager_get_client (_data_->_tmp1_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp3_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp4_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp4_ = _data_->cancellable;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_state_ = 1;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_get_device_from_path (_data_->self, _data_->_tmp0_, _data_->_tmp3_, _data_->_tmp4_, boxes_installer_media_new_for_path_ready, _data_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 660 "installer-media.c"
	_state_1:
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp5_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp5_ = boxes_installer_media_get_device_from_path_finish (_data_->self, _data_->_res_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->device = _data_->_tmp5_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp6_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp6_ = _data_->device;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_tmp6_ != NULL) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp7_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp7_ = _data_->device;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp8_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp8_ = _data_->media_manager;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp9_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp9_ = boxes_media_manager_get_os_db (_data_->_tmp8_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp10_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_state_ = 2;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		boxes_installer_media_get_media_info_from_device (_data_->self, _data_->_tmp7_, _data_->_tmp10_, boxes_installer_media_new_for_path_ready, _data_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return FALSE;
#line 696 "installer-media.c"
		_state_2:
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		boxes_installer_media_get_media_info_from_device_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_error_free (_data_->_inner_error_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->device);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			if (_data_->_state_ == 0) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 712 "installer-media.c"
			} else {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 716 "installer-media.c"
			}
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_object_unref (_data_->_async_result);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			return FALSE;
#line 722 "installer-media.c"
		}
	} else {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->self->from_image = TRUE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp12_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp12_ = _data_->media_manager;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp13_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp13_ = boxes_media_manager_get_os_db (_data_->_tmp12_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp14_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp14_ = _data_->_tmp13_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp15_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp15_ = _data_->self->device_file;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp16_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp16_ = _data_->cancellable;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_state_ = 3;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		boxes_os_database_guess_os_from_install_media_path (_data_->_tmp14_, _data_->_tmp15_, _data_->_tmp16_, boxes_installer_media_new_for_path_ready, _data_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return FALSE;
#line 753 "installer-media.c"
		_state_3:
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp17_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp17_ = boxes_os_database_guess_os_from_install_media_path_finish (_data_->_tmp14_, _data_->_res_, &_data_->_inner_error_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp11_ = _data_->_tmp17_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_error_free (_data_->_inner_error_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->device);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			if (_data_->_state_ == 0) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 773 "installer-media.c"
			} else {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 777 "installer-media.c"
			}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_object_unref (_data_->_async_result);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			return FALSE;
#line 783 "installer-media.c"
		}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp18_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp18_ = _data_->_tmp11_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp11_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->self->os_media);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->self->os_media = _data_->_tmp18_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp19_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp19_ = _data_->self->os_media;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (_data_->_tmp19_ != NULL) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp20_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp20_ = _data_->self->os_media;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp21_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp21_ = osinfo_media_get_os (_data_->_tmp20_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp22_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp22_ = _data_->_tmp21_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->self->os);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->self->os = _data_->_tmp22_;
#line 817 "installer-media.c"
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->_tmp11_);
#line 821 "installer-media.c"
	}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_label_setup (_data_->self, NULL);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp24_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp24_ = boxes_installer_media_get_architecture (_data_->self);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp25_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp23_ = _data_->_tmp25_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_tmp23_ == NULL) {
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp26_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp26_ = g_strdup ("i686");
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (_data_->_tmp23_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp23_ = _data_->_tmp26_;
#line 845 "installer-media.c"
	}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp27_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp27_ = _data_->_tmp23_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp23_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->architecture = _data_->_tmp27_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp28_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp28_ = _data_->media_manager;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp29_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp29_ = boxes_media_manager_get_os_db (_data_->_tmp28_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp30_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp30_ = _data_->_tmp29_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp31_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp31_ = _data_->self->os;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp32_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp32_ = _data_->architecture;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp33_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp33_ = boxes_os_database_get_resources_for_os (_data_->_tmp30_, _data_->_tmp31_, _data_->_tmp32_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->self->resources);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self->resources = _data_->_tmp33_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp36_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp36_ = _data_->architecture;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (g_strcmp0 (_data_->_tmp36_, "i686") == 0) {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp35_ = TRUE;
#line 891 "installer-media.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp37_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp37_ = _data_->architecture;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp35_ = g_strcmp0 (_data_->_tmp37_, "i386") == 0;
#line 899 "installer-media.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_tmp35_) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp38_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp38_ = _data_->self->resources;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp39_ = 0LL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp39_ = osinfo_resources_get_ram (_data_->_tmp38_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp40_ = 0LL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp41_ = 0LL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp41_ = CLAMP (_data_->_tmp40_, (gint64) OSINFO_MEBIBYTES, (gint64) G_MAXUINT32);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp34_ = _data_->_tmp41_;
#line 921 "installer-media.c"
	} else {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp42_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp42_ = _data_->self->resources;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp43_ = 0LL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp43_ = osinfo_resources_get_ram (_data_->_tmp42_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp44_ = 0LL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp44_ = _data_->_tmp43_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp45_ = 0LL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp45_ = CLAMP (_data_->_tmp44_, (gint64) OSINFO_MEBIBYTES, G_MAXINT64);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp34_ = _data_->_tmp45_;
#line 941 "installer-media.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp46_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp46_ = _data_->self->resources;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	osinfo_resources_set_ram (_data_->_tmp46_, _data_->_tmp34_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->architecture);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->_tmp23_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->device);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_state_ == 0) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 959 "installer-media.c"
	} else {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 963 "installer-media.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_unref (_data_->_async_result);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 969 "installer-media.c"
}


void boxes_installer_media_new_for_path (const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_construct_for_path (BOXES_TYPE_INSTALLER_MEDIA, path, media_manager, cancellable, _callback_, _user_data_);
#line 976 "installer-media.c"
}


BoxesInstallerMedia* boxes_installer_media_new_for_path_finish (GAsyncResult* _res_, GError** error) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return boxes_installer_media_construct_for_path_finish (_res_, error);
#line 983 "installer-media.c"
}


static void boxes_installer_media_real_set_direct_boot_params (BoxesInstallerMedia* self, GVirConfigDomainOs* os) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (os != NULL);
#line 990 "installer-media.c"
}


void boxes_installer_media_set_direct_boot_params (BoxesInstallerMedia* self, GVirConfigDomainOs* os) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->set_direct_boot_params (self, os);
#line 999 "installer-media.c"
}


static void boxes_installer_media_real_prepare_data_free (gpointer _data) {
	BoxesInstallerMediaPrepareData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->progress);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_slice_free (BoxesInstallerMediaPrepareData, _data_);
#line 1014 "installer-media.c"
}


static void boxes_installer_media_real_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesInstallerMediaPrepareData* _data_;
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesActivityProgress* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_slice_new0 (BoxesInstallerMediaPrepareData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_installer_media_real_prepare);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_installer_media_real_prepare_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = progress;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->progress);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->progress = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = cancellable;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->cancellable = _tmp4_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_real_prepare_co (_data_);
#line 1053 "installer-media.c"
}


static gboolean boxes_installer_media_real_prepare_finish (BoxesInstallerMedia* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesInstallerMediaPrepareData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _data_->result;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 1066 "installer-media.c"
}


static gboolean boxes_installer_media_real_prepare_co (BoxesInstallerMediaPrepareData* _data_) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	switch (_data_->_state_) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 0:
#line 1075 "installer-media.c"
		goto _state_0;
		default:
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_assert_not_reached ();
#line 1080 "installer-media.c"
	}
	_state_0:
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->result = TRUE;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_state_ == 0) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1089 "installer-media.c"
	} else {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1093 "installer-media.c"
	}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_unref (_data_->_async_result);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_state_ == 0) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1103 "installer-media.c"
	} else {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1107 "installer-media.c"
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_unref (_data_->_async_result);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 1113 "installer-media.c"
}


void boxes_installer_media_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->prepare (self, progress, cancellable, _callback_, _user_data_);
#line 1120 "installer-media.c"
}


gboolean boxes_installer_media_prepare_finish (BoxesInstallerMedia* self, GAsyncResult* _res_) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->prepare_finish (self, _res_);
#line 1127 "installer-media.c"
}


static void boxes_installer_media_real_prepare_for_installation_data_free (gpointer _data) {
	BoxesInstallerMediaPrepareForInstallationData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->vm_name);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_slice_free (BoxesInstallerMediaPrepareForInstallationData, _data_);
#line 1142 "installer-media.c"
}


static void boxes_installer_media_real_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesInstallerMediaPrepareForInstallationData* _data_;
	BoxesInstallerMedia* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_slice_new0 (BoxesInstallerMediaPrepareForInstallationData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_installer_media_real_prepare_for_installation);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_installer_media_real_prepare_for_installation_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = vm_name;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->vm_name);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->vm_name = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = cancellable;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->cancellable = _tmp4_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_real_prepare_for_installation_co (_data_);
#line 1181 "installer-media.c"
}


static void boxes_installer_media_real_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_) {
	BoxesInstallerMediaPrepareForInstallationData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1189 "installer-media.c"
}


static gboolean boxes_installer_media_real_prepare_for_installation_co (BoxesInstallerMediaPrepareForInstallationData* _data_) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	switch (_data_->_state_) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 0:
#line 1198 "installer-media.c"
		goto _state_0;
		default:
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_assert_not_reached ();
#line 1203 "installer-media.c"
	}
	_state_0:
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_state_ == 0) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1210 "installer-media.c"
	} else {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1214 "installer-media.c"
	}
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_unref (_data_->_async_result);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 1220 "installer-media.c"
}


void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->prepare_for_installation (self, vm_name, cancellable, _callback_, _user_data_);
#line 1227 "installer-media.c"
}


void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->prepare_for_installation_finish (self, _res_);
#line 1234 "installer-media.c"
}


static void boxes_installer_media_real_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name) {
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (vm_name != NULL);
#line 1241 "installer-media.c"
}


void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name) {
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->prepare_to_continue_installation (self, vm_name);
#line 1250 "installer-media.c"
}


static void boxes_installer_media_real_clean_up (BoxesInstallerMedia* self) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_clean_up_preparation_cache (self);
#line 1257 "installer-media.c"
}


void boxes_installer_media_clean_up (BoxesInstallerMedia* self) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->clean_up (self);
#line 1266 "installer-media.c"
}


static void boxes_installer_media_real_clean_up_preparation_cache (BoxesInstallerMedia* self) {
}


void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->clean_up_preparation_cache (self);
#line 1279 "installer-media.c"
}


static void boxes_installer_media_real_setup_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain) {
	GVirConfigDomainDiskType _tmp0_ = 0;
	gboolean _tmp1_ = FALSE;
	GVirConfigDomain* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (domain != NULL);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = self->from_image;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp1_) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = GVIR_CONFIG_DOMAIN_DISK_FILE;
#line 1296 "installer-media.c"
	} else {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = GVIR_CONFIG_DOMAIN_DISK_BLOCK;
#line 1300 "installer-media.c"
	}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = domain;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = self->device_file;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_add_cd_config (self, _tmp2_, _tmp0_, _tmp3_, "hdc", TRUE);
#line 1308 "installer-media.c"
}


void boxes_installer_media_setup_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain) {
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->setup_domain_config (self, domain);
#line 1317 "installer-media.c"
}


static void boxes_installer_media_real_setup_post_install_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain) {
	GVirConfigDomain* _tmp0_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (domain != NULL);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = domain;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_eject_cdrom_media (self, _tmp0_);
#line 1329 "installer-media.c"
}


void boxes_installer_media_setup_post_install_domain_config (BoxesInstallerMedia* self, GVirConfigDomain* domain) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->setup_post_install_domain_config (self, domain);
#line 1338 "installer-media.c"
}


static void boxes_installer_media_real_populate_setup_box (BoxesInstallerMedia* self, GtkBox* setup_box) {
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (setup_box != NULL);
#line 1345 "installer-media.c"
}


void boxes_installer_media_populate_setup_box (BoxesInstallerMedia* self, GtkBox* setup_box) {
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_GET_CLASS (self)->populate_setup_box (self, setup_box);
#line 1354 "installer-media.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 1361 "installer-media.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_list_free (self);
#line 1370 "installer-media.c"
}


static GList* boxes_installer_media_real_get_vm_properties (BoxesInstallerMedia* self) {
	GList* result = NULL;
	GList* properties = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesPair* _tmp2_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	properties = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = _ ("System");
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = self->label;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = boxes_pair_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, _tmp0_, _tmp1_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	properties = g_list_append (properties, _tmp2_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = properties;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 1394 "installer-media.c"
}


GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_vm_properties (self);
#line 1403 "installer-media.c"
}


gboolean boxes_installer_media_is_architecture_compatible (BoxesInstallerMedia* self, const gchar* architecture) {
	gboolean result = FALSE;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	BoxesCPUArchCompatibility compatibility = 0;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	BoxesCPUArchCompatibility _tmp8_ = 0;
	BoxesCPUArchCompatibility _tmp9_ = 0;
	BoxesCPUArchCompatibility _tmp10_ = 0;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (architecture != NULL, FALSE);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = boxes_installer_media_get_architecture (self);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = _tmp0_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = _tmp1_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = _tmp2_ == NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_tmp2_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp3_) {
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		result = TRUE;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return result;
#line 1441 "installer-media.c"
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = architecture;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = boxes_installer_media_get_architecture (self);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp6_ = _tmp5_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp7_ = _tmp6_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp8_ = boxes_compare_cpu_architectures (_tmp4_, _tmp7_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp9_ = _tmp8_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_tmp7_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	compatibility = _tmp9_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp10_ = compatibility;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _tmp10_ != BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 1465 "installer-media.c"
}


static BoxesVMCreator* boxes_installer_media_real_get_vm_creator (BoxesInstallerMedia* self) {
	BoxesVMCreator* result = NULL;
	BoxesVMCreator* _tmp0_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = boxes_vm_creator_new (self);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _tmp0_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 1478 "installer-media.c"
}


BoxesVMCreator* boxes_installer_media_get_vm_creator (BoxesInstallerMedia* self) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_vm_creator (self);
#line 1487 "installer-media.c"
}


void boxes_installer_media_add_cd_config (BoxesInstallerMedia* self, GVirConfigDomain* domain, GVirConfigDomainDiskType type, const gchar* iso_path, const gchar* device_name, gboolean mandatory) {
	GVirConfigDomainDisk* disk = NULL;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GVirConfigDomainDiskType _tmp2_ = 0;
	GVirConfigDomainDisk* _tmp3_ = NULL;
	GVirConfigDomainDisk* _tmp4_ = NULL;
	GVirConfigDomainDisk* _tmp5_ = NULL;
	GVirConfigDomainDisk* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GVirConfigDomainDisk* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	GVirConfigDomain* _tmp14_ = NULL;
	GVirConfigDomainDisk* _tmp15_ = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (domain != NULL);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (device_name != NULL);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = gvir_config_domain_disk_new ();
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	disk = _tmp0_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = disk;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = type;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_disk_set_type (_tmp1_, _tmp2_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = disk;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_disk_set_guest_device_type (_tmp3_, GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = disk;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_disk_set_driver_name (_tmp4_, "qemu");
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = disk;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_disk_set_driver_format (_tmp5_, GVIR_CONFIG_DOMAIN_DISK_FORMAT_RAW);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp6_ = disk;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp7_ = device_name;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_disk_set_target_dev (_tmp6_, _tmp7_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp8_ = iso_path;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp8_ != NULL) {
#line 1544 "installer-media.c"
		GVirConfigDomainDisk* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp9_ = disk;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp10_ = iso_path;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		gvir_config_domain_disk_set_source (_tmp9_, _tmp10_);
#line 1553 "installer-media.c"
	}
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp11_ = disk;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_disk_set_target_bus (_tmp11_, GVIR_CONFIG_DOMAIN_DISK_BUS_IDE);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp12_ = mandatory;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp12_) {
#line 1563 "installer-media.c"
		GVirConfigDomainDisk* _tmp13_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp13_ = disk;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		gvir_config_domain_disk_set_startup_policy (_tmp13_, GVIR_CONFIG_DOMAIN_DISK_STARTUP_POLICY_MANDATORY);
#line 1569 "installer-media.c"
	}
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp14_ = domain;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp15_ = disk;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_add_device (_tmp14_, (GVirConfigDomainDevice*) _tmp15_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (disk);
#line 1579 "installer-media.c"
}


static gint string_index_of (const gchar* self, const gchar* needle, gint start_index) {
	gint result = 0;
	gchar* _result_ = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 987 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 987 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, 0);
#line 988 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = start_index;
#line 988 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = needle;
#line 988 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp2_ = strstr (((gchar*) self) + _tmp0_, (gchar*) _tmp1_);
#line 988 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_result_ = _tmp2_;
#line 990 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3_ = _result_;
#line 990 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 1606 "installer-media.c"
		gchar* _tmp4_ = NULL;
#line 991 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp4_ = _result_;
#line 991 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		result = (gint) (_tmp4_ - ((gchar*) self));
#line 991 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 1614 "installer-media.c"
	} else {
#line 993 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		result = -1;
#line 993 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		return result;
#line 1620 "installer-media.c"
	}
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1328 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1329 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1329 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1329 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1330 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1330 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 1654 "installer-media.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1331 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1331 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1331 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 1663 "installer-media.c"
	}
#line 1333 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1333 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 1669 "installer-media.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1334 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1334 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1334 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 1678 "installer-media.c"
	}
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 1684 "installer-media.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 1693 "installer-media.c"
	} else {
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 1697 "installer-media.c"
	}
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 1705 "installer-media.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 1714 "installer-media.c"
	} else {
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 1718 "installer-media.c"
	}
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1338 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1338 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1338 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 1740 "installer-media.c"
}


void boxes_installer_media_label_setup (BoxesInstallerMedia* self, const gchar* label) {
	const gchar* _tmp0_ = NULL;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = label;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp0_ != NULL) {
#line 1752 "installer-media.c"
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp1_ = label;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp2_ = g_strdup (_tmp1_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (self->label);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		self->label = _tmp2_;
#line 1763 "installer-media.c"
	} else {
		gboolean _tmp3_ = FALSE;
		OsinfoOs* _tmp4_ = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp4_ = self->os;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (_tmp4_ != NULL) {
#line 1771 "installer-media.c"
			OsinfoMedia* _tmp5_ = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp5_ = self->os_media;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp3_ = _tmp5_ != NULL;
#line 1777 "installer-media.c"
		} else {
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp3_ = FALSE;
#line 1781 "installer-media.c"
		}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (_tmp3_) {
#line 1785 "installer-media.c"
			OsinfoOsVariantList* variants = NULL;
			OsinfoMedia* _tmp6_ = NULL;
			OsinfoOsVariantList* _tmp7_ = NULL;
			OsinfoOsVariantList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp6_ = self->os_media;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp7_ = osinfo_media_get_os_variants (_tmp6_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			variants = _tmp7_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp8_ = variants;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp9_ = osinfo_list_get_length ((OsinfoList*) _tmp8_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			if (_tmp9_ > 0) {
#line 1803 "installer-media.c"
				OsinfoOsVariantList* _tmp10_ = NULL;
				OsinfoEntity* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
				gchar* _tmp13_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp10_ = variants;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp11_ = osinfo_list_get_nth ((OsinfoList*) _tmp10_, 0);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp12_ = osinfo_os_variant_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, osinfo_os_variant_get_type ()) ? ((OsinfoOsVariant*) _tmp11_) : NULL);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp13_ = g_strdup (_tmp12_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (self->label);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				self->label = _tmp13_;
#line 1820 "installer-media.c"
			} else {
				OsinfoOs* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp14_ = self->os;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp15_ = osinfo_product_get_name ((OsinfoProduct*) _tmp14_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp16_ = g_strdup (_tmp15_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (self->label);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				self->label = _tmp16_;
#line 1835 "installer-media.c"
			}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (variants);
#line 1839 "installer-media.c"
		} else {
			gchar* basename = NULL;
			const gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gint ext_index = 0;
			const gchar* _tmp19_ = NULL;
			gint _tmp20_ = 0;
			gchar* _tmp21_ = NULL;
			gint _tmp22_ = 0;
			gchar* _tmp28_ = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp17_ = self->device_file;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp18_ = boxes_get_utf8_basename (_tmp17_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			basename = _tmp18_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp19_ = basename;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp20_ = string_index_of (_tmp19_, ".", 0);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			ext_index = _tmp20_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp22_ = ext_index;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			if (_tmp22_ > 0) {
#line 1866 "installer-media.c"
				const gchar* _tmp23_ = NULL;
				gint _tmp24_ = 0;
				gchar* _tmp25_ = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp23_ = basename;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp24_ = ext_index;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp25_ = string_slice (_tmp23_, (glong) 0, (glong) _tmp24_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (_tmp21_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp21_ = _tmp25_;
#line 1880 "installer-media.c"
			} else {
				const gchar* _tmp26_ = NULL;
				gchar* _tmp27_ = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp26_ = basename;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp27_ = g_strdup (_tmp26_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (_tmp21_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp21_ = _tmp27_;
#line 1892 "installer-media.c"
			}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp28_ = g_strdup (_tmp21_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (self->label);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			self->label = _tmp28_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (_tmp21_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (basename);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			return;
#line 1906 "installer-media.c"
		}
	}
}


static void boxes_installer_media_get_device_from_path_data_free (gpointer _data) {
	BoxesInstallerMediaGetDeviceFromPathData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->client);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_slice_free (BoxesInstallerMediaGetDeviceFromPathData, _data_);
#line 1927 "installer-media.c"
}


static void boxes_installer_media_get_device_from_path (BoxesInstallerMedia* self, const gchar* path, GUdevClient* client, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesInstallerMediaGetDeviceFromPathData* _data_;
	BoxesInstallerMedia* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GUdevClient* _tmp3_ = NULL;
	GUdevClient* _tmp4_ = NULL;
	GCancellable* _tmp5_ = NULL;
	GCancellable* _tmp6_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_slice_new0 (BoxesInstallerMediaGetDeviceFromPathData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_installer_media_get_device_from_path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_installer_media_get_device_from_path_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = path;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->path);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->path = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = client;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->client);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->client = _tmp4_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = cancellable;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->cancellable = _tmp6_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_get_device_from_path_co (_data_);
#line 1976 "installer-media.c"
}


static GUdevDevice* boxes_installer_media_get_device_from_path_finish (BoxesInstallerMedia* self, GAsyncResult* _res_) {
	GUdevDevice* result;
	BoxesInstallerMediaGetDeviceFromPathData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _data_->result;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->result = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 1991 "installer-media.c"
}


static void boxes_installer_media_get_device_from_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesInstallerMediaGetDeviceFromPathData* _data_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = _user_data_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_source_object_ = source_object;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_res_ = _res_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_get_device_from_path_co (_data_);
#line 2005 "installer-media.c"
}


static gboolean boxes_installer_media_get_device_from_path_co (BoxesInstallerMediaGetDeviceFromPathData* _data_) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	switch (_data_->_state_) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 0:
#line 2014 "installer-media.c"
		goto _state_0;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 1:
#line 2018 "installer-media.c"
		goto _state_1;
		default:
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_assert_not_reached ();
#line 2023 "installer-media.c"
	}
	_state_0:
	{
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp0_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp0_ = _data_->path;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp1_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp1_ = g_file_new_for_path (_data_->_tmp0_);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->mount_dir = _data_->_tmp1_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp2_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp2_ = _data_->cancellable;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_state_ = 1;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_file_find_enclosing_mount_async (_data_->mount_dir, G_PRIORITY_DEFAULT, _data_->_tmp2_, boxes_installer_media_get_device_from_path_ready, _data_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return FALSE;
#line 2047 "installer-media.c"
		_state_1:
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp3_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp3_ = g_file_find_enclosing_mount_finish (_data_->mount_dir, _data_->_res_, &_data_->_inner_error_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->mount = _data_->_tmp3_;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->mount_dir);
#line 2059 "installer-media.c"
			goto __catch8_g_error;
		}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp4_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp4_ = g_mount_get_root (_data_->mount);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->root_dir = _data_->_tmp4_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp5_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp5_ = _data_->root_dir;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp6_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp6_ = g_file_get_path (_data_->_tmp5_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp7_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp8_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp8_ = g_file_get_path (_data_->mount_dir);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp9_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp10_ = FALSE;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp10_ = g_strcmp0 (_data_->_tmp7_, _data_->_tmp9_) == 0;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (_data_->_tmp9_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (_data_->_tmp7_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (_data_->_tmp10_) {
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp11_ = NULL;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp11_ = g_mount_get_volume (_data_->mount);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->volume = _data_->_tmp11_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp12_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp12_ = _data_->volume;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp13_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp13_ = g_volume_get_identifier (_data_->_tmp12_, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (_data_->self->device_file);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->self->device_file = _data_->_tmp13_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp14_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp14_ = _data_->path;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp15_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp15_ = g_strdup (_data_->_tmp14_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (_data_->self->mount_point);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->self->mount_point = _data_->_tmp15_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->volume);
#line 2130 "installer-media.c"
		} else {
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp16_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp16_ = _data_->path;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp17_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp17_ = g_strdup (_data_->_tmp16_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (_data_->self->device_file);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->self->device_file = _data_->_tmp17_;
#line 2144 "installer-media.c"
		}
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->root_dir);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->mount);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->mount_dir);
#line 2152 "installer-media.c"
	}
	goto __finally8;
	__catch8_g_error:
	{
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_inner_error_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp18_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp18_ = _data_->path;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp19_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp19_ = g_strdup (_data_->_tmp18_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (_data_->self->device_file);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->self->device_file = _data_->_tmp19_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_error_free0 (_data_->_error_);
#line 2175 "installer-media.c"
	}
	__finally8:
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_clear_error (&_data_->_inner_error_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return FALSE;
#line 2186 "installer-media.c"
	}
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp20_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp20_ = _data_->client;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp21_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp21_ = _data_->self->device_file;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp22_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp22_ = g_udev_client_query_by_device_file (_data_->_tmp20_, _data_->_tmp21_);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->result = _data_->_tmp22_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_state_ == 0) {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2206 "installer-media.c"
	} else {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2210 "installer-media.c"
	}
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_unref (_data_->_async_result);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_state_ == 0) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2220 "installer-media.c"
	} else {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2224 "installer-media.c"
	}
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_unref (_data_->_async_result);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 2230 "installer-media.c"
}


static void boxes_installer_media_get_media_info_from_device_data_free (gpointer _data) {
	BoxesInstallerMediaGetMediaInfoFromDeviceData* _data_;
	_data_ = _data;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->device);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->os_db);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_slice_free (BoxesInstallerMediaGetMediaInfoFromDeviceData, _data_);
#line 2245 "installer-media.c"
}


static void boxes_installer_media_get_media_info_from_device (BoxesInstallerMedia* self, GUdevDevice* device, BoxesOSDatabase* os_db, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesInstallerMediaGetMediaInfoFromDeviceData* _data_;
	BoxesInstallerMedia* _tmp0_ = NULL;
	GUdevDevice* _tmp1_ = NULL;
	GUdevDevice* _tmp2_ = NULL;
	BoxesOSDatabase* _tmp3_ = NULL;
	BoxesOSDatabase* _tmp4_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_slice_new0 (BoxesInstallerMediaGetMediaInfoFromDeviceData);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_installer_media_get_media_info_from_device);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_installer_media_get_media_info_from_device_data_free);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = device;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->device);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->device = _tmp2_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = os_db;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_data_->os_db);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->os_db = _tmp4_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_get_media_info_from_device_co (_data_);
#line 2284 "installer-media.c"
}


static void boxes_installer_media_get_media_info_from_device_finish (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error) {
	BoxesInstallerMediaGetMediaInfoFromDeviceData* _data_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return;
#line 2294 "installer-media.c"
	}
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2298 "installer-media.c"
}


static void boxes_installer_media_get_media_info_from_device_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesInstallerMediaGetMediaInfoFromDeviceData* _data_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_ = _user_data_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_source_object_ = source_object;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_res_ = _res_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_get_media_info_from_device_co (_data_);
#line 2312 "installer-media.c"
}


static gboolean boxes_installer_media_get_media_info_from_device_co (BoxesInstallerMediaGetMediaInfoFromDeviceData* _data_) {
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	switch (_data_->_state_) {
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 0:
#line 2321 "installer-media.c"
		goto _state_0;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 1:
#line 2325 "installer-media.c"
		goto _state_1;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case 2:
#line 2329 "installer-media.c"
		goto _state_2;
		default:
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_assert_not_reached ();
#line 2334 "installer-media.c"
	}
	_state_0:
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp1_ = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp1_ = _data_->device;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp2_ = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp2_ = g_udev_device_get_property (_data_->_tmp1_, "ID_FS_BOOT_SYSTEM_ID");
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_tmp2_ == NULL) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp3_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp3_ = _data_->device;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp4_ = FALSE;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp4_ = g_udev_device_get_property_as_boolean (_data_->_tmp3_, "OSINFO_BOOTABLE");
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp0_ = !_data_->_tmp4_;
#line 2357 "installer-media.c"
	} else {
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp0_ = FALSE;
#line 2361 "installer-media.c"
	}
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_tmp0_) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp5_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp5_ = _data_->self->device_file;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp6_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp6_ = g_error_new (BOXES_OS_DATABASE_ERROR, BOXES_OS_DATABASE_ERROR_NON_BOOTABLE, "Media %s is not bootable.", _data_->_tmp5_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_inner_error_ = _data_->_tmp6_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_error_free (_data_->_inner_error_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (_data_->_state_ == 0) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2383 "installer-media.c"
		} else {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2387 "installer-media.c"
		}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_object_unref (_data_->_async_result);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return FALSE;
#line 2393 "installer-media.c"
	}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp7_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp7_ = _data_->device;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp8_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp8_ = boxes_installer_media_get_decoded_udev_property (_data_->self, _data_->_tmp7_, "ID_FS_LABEL_ENC");
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->self->label);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->self->label = _data_->_tmp8_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp10_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp10_ = _data_->device;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp11_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp11_ = g_udev_device_get_property (_data_->_tmp10_, "OSINFO_INSTALLER");
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp9_ = _data_->_tmp11_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_tmp9_ == NULL) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp12_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp12_ = _data_->device;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp13_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp13_ = g_udev_device_get_property (_data_->_tmp12_, "OSINFO_LIVE");
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp9_ = _data_->_tmp13_;
#line 2429 "installer-media.c"
	}
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp14_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp14_ = g_strdup (_data_->_tmp9_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->os_id = _data_->_tmp14_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp15_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_data_->_tmp15_ = _data_->os_id;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_tmp15_ != NULL) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp17_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp17_ = _data_->os_db;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp18_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp18_ = _data_->os_id;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_state_ = 1;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		boxes_os_database_get_os_by_id (_data_->_tmp17_, _data_->_tmp18_, boxes_installer_media_get_media_info_from_device_ready, _data_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return FALSE;
#line 2457 "installer-media.c"
		_state_1:
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp19_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp19_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp17_, _data_->_res_, &_data_->_inner_error_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp16_ = _data_->_tmp19_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_error_free (_data_->_inner_error_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (_data_->os_id);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			if (_data_->_state_ == 0) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2477 "installer-media.c"
			} else {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2481 "installer-media.c"
			}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_object_unref (_data_->_async_result);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			return FALSE;
#line 2487 "installer-media.c"
		}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp20_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp20_ = _data_->_tmp16_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp16_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->self->os);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->self->os = _data_->_tmp20_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp21_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp21_ = _data_->device;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp22_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp22_ = g_udev_device_get_property (_data_->_tmp21_, "OSINFO_MEDIA");
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp23_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp23_ = g_strdup (_data_->_tmp22_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->media_id = _data_->_tmp23_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp24_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp24_ = _data_->media_id;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (_data_->_tmp24_ != NULL) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp26_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp26_ = _data_->os_db;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp27_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp27_ = _data_->self->os;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp28_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp28_ = _data_->media_id;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp29_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp29_ = boxes_os_database_get_media_by_id (_data_->_tmp26_, _data_->_tmp27_, _data_->_tmp28_, &_data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp25_ = _data_->_tmp29_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_error_free (_data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (_data_->media_id);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_object_unref0 (_data_->_tmp16_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (_data_->os_id);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (_data_->_state_ == 0) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2553 "installer-media.c"
				} else {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 2557 "installer-media.c"
				}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_object_unref (_data_->_async_result);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				return FALSE;
#line 2563 "installer-media.c"
			}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp30_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp30_ = _data_->_tmp25_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp25_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->self->os_media);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->self->os_media = _data_->_tmp30_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->_tmp25_);
#line 2577 "installer-media.c"
		}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (_data_->media_id);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->_tmp16_);
#line 2583 "installer-media.c"
	} else {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp31_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp31_ = _data_->self->device_file;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp32_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp32_ = osinfo_media_new (_data_->_tmp31_, OSINFO_ARCHITECTURE_ALL);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->media = _data_->_tmp32_;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp33_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp33_ = _data_->media;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp34_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp34_ = _data_->self->label;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_object_set (_data_->_tmp33_, "volume-id", _data_->_tmp34_, NULL);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp35_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp35_ = _data_->device;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp36_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp36_ = g_strdup ("ID_FS_SYSTEM_ID");
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp37_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp37_ = g_strdup ("ID_FS_PUBLISHER_ID");
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp38_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp38_ = g_strdup ("ID_FS_APPLICATION_ID");
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp39_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp39_ = g_new0 (gchar*, 3 + 1);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp39_[0] = _data_->_tmp36_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp39_[1] = _data_->_tmp37_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp39_[2] = _data_->_tmp38_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp40_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp40__length1 = 0;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp40__length1 = 3;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp41_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp41_ = g_strdup (OSINFO_MEDIA_PROP_SYSTEM_ID);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp42_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp42_ = g_strdup (OSINFO_MEDIA_PROP_PUBLISHER_ID);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp43_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp43_ = g_strdup (OSINFO_MEDIA_PROP_APPLICATION_ID);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp44_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp44_ = g_new0 (gchar*, 3 + 1);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp44_[0] = _data_->_tmp41_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp44_[1] = _data_->_tmp42_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp44_[2] = _data_->_tmp43_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp45_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp45__length1 = 0;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp45_ = _data_->_tmp44_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp45__length1 = 3;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp46_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp46_ = _data_->media;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		boxes_installer_media_get_decoded_udev_properties_for_media (_data_->self, _data_->_tmp35_, _data_->_tmp40_, 3, _data_->_tmp45_, 3, _data_->_tmp46_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp45_ = (_vala_array_free (_data_->_tmp45_, _data_->_tmp45__length1, (GDestroyNotify) g_free), NULL);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp40_ = (_vala_array_free (_data_->_tmp40_, _data_->_tmp40__length1, (GDestroyNotify) g_free), NULL);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp48_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp48_ = _data_->os_db;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp49_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp49_ = _data_->media;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_state_ = 2;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		boxes_os_database_guess_os_from_install_media (_data_->_tmp48_, _data_->_tmp49_, boxes_installer_media_get_media_info_from_device_ready, _data_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return FALSE;
#line 2693 "installer-media.c"
		_state_2:
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp50_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp50_ = boxes_os_database_guess_os_from_install_media_finish (_data_->_tmp48_, _data_->_res_, &_data_->_inner_error_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp47_ = _data_->_tmp50_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_error_free (_data_->_inner_error_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->media);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_free0 (_data_->os_id);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			if (_data_->_state_ == 0) {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2715 "installer-media.c"
			} else {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2719 "installer-media.c"
			}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			g_object_unref (_data_->_async_result);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			return FALSE;
#line 2725 "installer-media.c"
		}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp51_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp51_ = _data_->_tmp47_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp47_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->self->os_media);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->self->os_media = _data_->_tmp51_;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp52_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_data_->_tmp52_ = _data_->self->os_media;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		if (_data_->_tmp52_ != NULL) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp53_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp53_ = _data_->self->os_media;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp54_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp54_ = osinfo_media_get_os (_data_->_tmp53_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp55_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->_tmp55_ = _data_->_tmp54_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_g_object_unref0 (_data_->self->os);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_data_->self->os = _data_->_tmp55_;
#line 2759 "installer-media.c"
		}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->_tmp47_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_data_->media);
#line 2765 "installer-media.c"
	}
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (_data_->os_id);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_data_->_state_ == 0) {
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2773 "installer-media.c"
	} else {
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2777 "installer-media.c"
	}
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_unref (_data_->_async_result);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return FALSE;
#line 2783 "installer-media.c"
}


static void boxes_installer_media_get_decoded_udev_properties_for_media (BoxesInstallerMedia* self, GUdevDevice* device, gchar** udev_props, int udev_props_length1, gchar** media_props, int media_props_length1, OsinfoMedia* media) {
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (device != NULL);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (media != NULL);
#line 2794 "installer-media.c"
	{
		gint i = 0;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		i = 0;
#line 2799 "installer-media.c"
		{
			gboolean _tmp0_ = FALSE;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp0_ = TRUE;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			while (TRUE) {
#line 2806 "installer-media.c"
				gint _tmp2_ = 0;
				gchar** _tmp3_ = NULL;
				gint _tmp3__length1 = 0;
				gchar* val = NULL;
				GUdevDevice* _tmp4_ = NULL;
				gchar** _tmp5_ = NULL;
				gint _tmp5__length1 = 0;
				gint _tmp6_ = 0;
				const gchar* _tmp7_ = NULL;
				gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (!_tmp0_) {
#line 2820 "installer-media.c"
					gint _tmp1_ = 0;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp1_ = i;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					i = _tmp1_ + 1;
#line 2826 "installer-media.c"
				}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp0_ = FALSE;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp2_ = i;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp3_ = udev_props;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp3__length1 = udev_props_length1;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (!(_tmp2_ < _tmp3__length1)) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					break;
#line 2840 "installer-media.c"
				}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp4_ = device;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp5_ = udev_props;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp5__length1 = udev_props_length1;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp6_ = i;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp7_ = _tmp5_[_tmp6_];
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp8_ = boxes_installer_media_get_decoded_udev_property (self, _tmp4_, _tmp7_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				val = _tmp8_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp9_ = val;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (_tmp9_ != NULL) {
#line 2860 "installer-media.c"
					OsinfoMedia* _tmp10_ = NULL;
					gchar** _tmp11_ = NULL;
					gint _tmp11__length1 = 0;
					gint _tmp12_ = 0;
					const gchar* _tmp13_ = NULL;
					const gchar* _tmp14_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp10_ = media;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp11_ = media_props;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp11__length1 = media_props_length1;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp12_ = i;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp13_ = _tmp11_[_tmp12_];
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp14_ = val;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					g_object_set ((GObject*) _tmp10_, _tmp13_, _tmp14_, NULL);
#line 2881 "installer-media.c"
				}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (val);
#line 2885 "installer-media.c"
			}
		}
	}
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 1086 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 1087 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 2906 "installer-media.c"
}


static gchar* boxes_installer_media_get_decoded_udev_property (BoxesInstallerMedia* self, GUdevDevice* device, const gchar* property_name) {
	gchar* result = NULL;
	gchar* encoded = NULL;
	GUdevDevice* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* decoded = NULL;
	gchar* _tmp5_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (device != NULL, NULL);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (property_name != NULL, NULL);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = device;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = property_name;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = g_udev_device_get_property (_tmp0_, _tmp1_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	encoded = _tmp3_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = encoded;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp4_ == NULL) {
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		result = NULL;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (encoded);
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		return result;
#line 2946 "installer-media.c"
	}
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = g_strdup ("");
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	decoded = _tmp5_;
#line 2952 "installer-media.c"
	{
		gint i = 0;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		i = 0;
#line 2957 "installer-media.c"
		{
			gboolean _tmp6_ = FALSE;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp6_ = TRUE;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			while (TRUE) {
#line 2964 "installer-media.c"
				gint _tmp7_ = 0;
				const gchar* _tmp8_ = NULL;
				gint _tmp9_ = 0;
				gint _tmp10_ = 0;
				guint x = 0U;
				const gchar* _tmp11_ = NULL;
				gint _tmp12_ = 0;
				const gchar* _tmp13_ = NULL;
				gint _tmp14_ = 0;
				gint _tmp15_ = 0;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
				gint _tmp18_ = 0;
				gboolean _tmp19_ = FALSE;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (!_tmp6_) {
#line 2981 "installer-media.c"
				}
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp6_ = FALSE;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp7_ = i;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp8_ = encoded;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp9_ = strlen (_tmp8_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp10_ = _tmp9_;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (!(_tmp7_ < _tmp10_)) {
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					break;
#line 2997 "installer-media.c"
				}
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp11_ = encoded;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp12_ = i;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp13_ = encoded;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp14_ = strlen (_tmp13_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp15_ = _tmp14_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp16_ = string_slice (_tmp11_, (glong) _tmp12_, (glong) _tmp15_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp17_ = _tmp16_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp18_ = sscanf (_tmp17_, "\\x%02x", &x);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp19_ = _tmp18_ > 0;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_free0 (_tmp17_);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (_tmp19_) {
#line 3021 "installer-media.c"
					const gchar* _tmp20_ = NULL;
					guint _tmp21_ = 0U;
					gchar* _tmp22_ = NULL;
					gchar* _tmp23_ = NULL;
					gchar* _tmp24_ = NULL;
					gint _tmp25_ = 0;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp20_ = decoded;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp21_ = x;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp22_ = g_strdup_printf ("%c", (gchar) _tmp21_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp23_ = _tmp22_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp24_ = g_strconcat (_tmp20_, _tmp23_, NULL);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_g_free0 (decoded);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					decoded = _tmp24_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_g_free0 (_tmp23_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp25_ = i;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					i = _tmp25_ + 4;
#line 3048 "installer-media.c"
				} else {
					const gchar* _tmp26_ = NULL;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gchar _tmp29_ = '\0';
					gchar* _tmp30_ = NULL;
					gchar* _tmp31_ = NULL;
					gchar* _tmp32_ = NULL;
					gint _tmp33_ = 0;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp26_ = decoded;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp27_ = encoded;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp28_ = i;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp29_ = string_get (_tmp27_, (glong) _tmp28_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp30_ = g_strdup_printf ("%c", _tmp29_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp31_ = _tmp30_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp32_ = g_strconcat (_tmp26_, _tmp31_, NULL);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_g_free0 (decoded);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					decoded = _tmp32_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_g_free0 (_tmp31_);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp33_ = i;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					i = _tmp33_ + 1;
#line 3082 "installer-media.c"
				}
			}
		}
	}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = decoded;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (encoded);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3093 "installer-media.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 3100 "installer-media.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_list_free (self);
#line 3109 "installer-media.c"
}


static void boxes_installer_media_eject_cdrom_media (BoxesInstallerMedia* self, GVirConfigDomain* domain) {
	GList* devices = NULL;
	GVirConfigDomain* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GVirConfigDomain* _tmp14_ = NULL;
	GList* _tmp15_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (self != NULL);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_if_fail (domain != NULL);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = domain;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = gvir_config_domain_get_devices (_tmp0_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	devices = _tmp1_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = devices;
#line 3132 "installer-media.c"
	{
		GList* device_collection = NULL;
		GList* device_it = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		device_collection = _tmp2_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		for (device_it = device_collection; device_it != NULL; device_it = device_it->next) {
#line 3140 "installer-media.c"
			GVirConfigDomainDevice* _tmp3_ = NULL;
			GVirConfigDomainDevice* device = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			_tmp3_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_it->data);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
			device = _tmp3_;
#line 3147 "installer-media.c"
			{
				GVirConfigDomainDevice* _tmp4_ = NULL;
				GVirConfigDomainDisk* disk = NULL;
				GVirConfigDomainDevice* _tmp5_ = NULL;
				GVirConfigDomainDisk* _tmp6_ = NULL;
				GVirConfigDomainDiskGuestDeviceType disk_type = 0;
				GVirConfigDomainDisk* _tmp7_ = NULL;
				GVirConfigDomainDiskGuestDeviceType _tmp8_ = 0;
				GVirConfigDomainDiskGuestDeviceType _tmp9_ = 0;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp4_ = device;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gvir_config_domain_disk_get_type ())) {
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_g_object_unref0 (device);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					continue;
#line 3165 "installer-media.c"
				}
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp5_ = device;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp5_) : NULL);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				disk = _tmp6_;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp7_ = disk;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp8_ = gvir_config_domain_disk_get_guest_device_type (_tmp7_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				disk_type = _tmp8_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_tmp9_ = disk_type;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				if (_tmp9_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM) {
#line 3183 "installer-media.c"
					GVirConfigDomainDisk* _tmp10_ = NULL;
					gboolean _tmp11_ = FALSE;
					gboolean _tmp12_ = FALSE;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp10_ = disk;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					gvir_config_domain_disk_set_startup_policy (_tmp10_, GVIR_CONFIG_DOMAIN_DISK_STARTUP_POLICY_OPTIONAL);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp11_ = boxes_installer_media_get_live (self);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					_tmp12_ = _tmp11_;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
					if (!_tmp12_) {
#line 3197 "installer-media.c"
						GVirConfigDomainDisk* _tmp13_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
						_tmp13_ = disk;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
						gvir_config_domain_disk_set_source (_tmp13_, "");
#line 3203 "installer-media.c"
					}
				}
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_object_unref0 (disk);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
				_g_object_unref0 (device);
#line 3210 "installer-media.c"
			}
		}
	}
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp14_ = domain;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp15_ = devices;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	gvir_config_domain_set_devices (_tmp14_, _tmp15_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	__g_list_free__g_object_unref0_0 (devices);
#line 3222 "installer-media.c"
}


BoxesInstallerMedia* boxes_installer_media_construct (GType object_type) {
	BoxesInstallerMedia * self = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = (BoxesInstallerMedia*) g_object_new (object_type, NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return self;
#line 3232 "installer-media.c"
}


BoxesInstallerMedia* boxes_installer_media_new (void) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return boxes_installer_media_construct (BOXES_TYPE_INSTALLER_MEDIA);
#line 3239 "installer-media.c"
}


OsinfoDeviceList* boxes_installer_media_get_supported_devices (BoxesInstallerMedia* self) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_supported_devices (self);
#line 3248 "installer-media.c"
}


static OsinfoDeviceList* boxes_installer_media_real_get_supported_devices (BoxesInstallerMedia* base) {
	OsinfoDeviceList* result;
	BoxesInstallerMedia* self;
	OsinfoDeviceList* _tmp0_ = NULL;
	OsinfoOs* _tmp1_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = base;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = self->os;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp1_ != NULL) {
#line 3263 "installer-media.c"
		OsinfoOs* _tmp2_ = NULL;
		OsinfoDeviceList* _tmp3_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp2_ = self->os;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp3_ = osinfo_os_get_all_devices (_tmp2_, NULL);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_tmp0_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = _tmp3_;
#line 3274 "installer-media.c"
	} else {
		OsinfoDeviceList* _tmp4_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp4_ = osinfo_devicelist_new ();
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_object_unref0 (_tmp0_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = _tmp4_;
#line 3283 "installer-media.c"
	}
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3289 "installer-media.c"
}


guint64 boxes_installer_media_get_installed_size (BoxesInstallerMedia* self) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, 0ULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_installed_size (self);
#line 3298 "installer-media.c"
}


static guint64 boxes_installer_media_real_get_installed_size (BoxesInstallerMedia* base) {
	guint64 result;
	BoxesInstallerMedia* self;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = base;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = (guint64) 0;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3311 "installer-media.c"
}


gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_need_user_input_for_vm_creation (self);
#line 3320 "installer-media.c"
}


static gboolean boxes_installer_media_real_get_need_user_input_for_vm_creation (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesInstallerMedia* self;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = base;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = FALSE;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3333 "installer-media.c"
}


gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self) {
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_ready_to_create (self);
#line 3342 "installer-media.c"
}


static gboolean boxes_installer_media_real_get_ready_to_create (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesInstallerMedia* self;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = base;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = TRUE;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3355 "installer-media.c"
}


gboolean boxes_installer_media_get_supports_virtio_disk (BoxesInstallerMedia* self) {
	gboolean result;
	OsinfoDeviceList* _tmp0_ = NULL;
	OsinfoDeviceList* _tmp1_ = NULL;
	OsinfoDeviceList* _tmp2_ = NULL;
	OsinfoDevice* _tmp3_ = NULL;
	OsinfoDevice* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = boxes_installer_media_get_supported_devices (self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = _tmp0_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = _tmp1_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = boxes_find_device_by_prop (_tmp2_, OSINFO_DEVICE_PROP_NAME, "virtio-block");
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = _tmp3_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_tmp4_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_tmp2_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _tmp5_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3389 "installer-media.c"
}


gboolean boxes_installer_media_get_supports_virtio_net (BoxesInstallerMedia* self) {
	gboolean result;
	OsinfoDeviceList* _tmp0_ = NULL;
	OsinfoDeviceList* _tmp1_ = NULL;
	OsinfoDeviceList* _tmp2_ = NULL;
	OsinfoDevice* _tmp3_ = NULL;
	OsinfoDevice* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp0_ = boxes_installer_media_get_supported_devices (self);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = _tmp0_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp2_ = _tmp1_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp3_ = boxes_find_device_by_prop (_tmp2_, OSINFO_DEVICE_PROP_NAME, "virtio-net");
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp4_ = _tmp3_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_tmp4_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (_tmp2_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _tmp5_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3423 "installer-media.c"
}


gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_live (self);
#line 3432 "installer-media.c"
}


static gboolean boxes_installer_media_real_get_live (BoxesInstallerMedia* base) {
	gboolean result;
	BoxesInstallerMedia* self;
	gboolean _tmp0_ = FALSE;
	OsinfoMedia* _tmp1_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = base;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = self->os_media;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp1_ == NULL) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = TRUE;
#line 3449 "installer-media.c"
	} else {
		OsinfoMedia* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp2_ = self->os_media;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_object_get (_tmp2_, "live", &_tmp3_, NULL);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp4_ = _tmp3_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = _tmp4_;
#line 3462 "installer-media.c"
	}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _tmp0_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3468 "installer-media.c"
}


gchar* boxes_installer_media_get_architecture (BoxesInstallerMedia* self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return BOXES_INSTALLER_MEDIA_GET_CLASS (self)->get_architecture (self);
#line 3477 "installer-media.c"
}


static gchar* boxes_installer_media_real_get_architecture (BoxesInstallerMedia* base) {
	gchar* result;
	BoxesInstallerMedia* self;
	gchar* _tmp0_ = NULL;
	OsinfoMedia* _tmp1_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = base;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_tmp1_ = self->os_media;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	if (_tmp1_ != NULL) {
#line 3492 "installer-media.c"
		OsinfoMedia* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp2_ = self->os_media;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_object_get (_tmp2_, "architecture", &_tmp3_, NULL);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp4_ = _tmp3_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (_tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = _tmp4_;
#line 3506 "installer-media.c"
	} else {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_g_free0 (_tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		_tmp0_ = NULL;
#line 3512 "installer-media.c"
	}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	result = _tmp0_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	return result;
#line 3518 "installer-media.c"
}


static void boxes_installer_media_class_init (BoxesInstallerMediaClass * klass) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	boxes_installer_media_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->set_direct_boot_params = boxes_installer_media_real_set_direct_boot_params;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->prepare = boxes_installer_media_real_prepare;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_finish = boxes_installer_media_real_prepare_finish;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_for_installation = boxes_installer_media_real_prepare_for_installation;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_for_installation_finish = boxes_installer_media_real_prepare_for_installation_finish;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->prepare_to_continue_installation = boxes_installer_media_real_prepare_to_continue_installation;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->clean_up = boxes_installer_media_real_clean_up;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->clean_up_preparation_cache = boxes_installer_media_real_clean_up_preparation_cache;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->setup_domain_config = boxes_installer_media_real_setup_domain_config;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->setup_post_install_domain_config = boxes_installer_media_real_setup_post_install_domain_config;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->populate_setup_box = boxes_installer_media_real_populate_setup_box;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->get_vm_properties = boxes_installer_media_real_get_vm_properties;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	((BoxesInstallerMediaClass *) klass)->get_vm_creator = boxes_installer_media_real_get_vm_creator;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_supported_devices = boxes_installer_media_real_get_supported_devices;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_installed_size = boxes_installer_media_real_get_installed_size;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_need_user_input_for_vm_creation = boxes_installer_media_real_get_need_user_input_for_vm_creation;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_ready_to_create = boxes_installer_media_real_get_ready_to_create;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_live = boxes_installer_media_real_get_live;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	BOXES_INSTALLER_MEDIA_CLASS (klass)->get_architecture = boxes_installer_media_real_get_architecture;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_installer_media_get_property;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_installer_media_finalize;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_SUPPORTED_DEVICES, g_param_spec_object ("supported-devices", "supported-devices", "supported-devices", osinfo_devicelist_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_INSTALLED_SIZE, g_param_spec_uint64 ("installed-size", "installed-size", "installed-size", 0, G_MAXUINT64, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_NEED_USER_INPUT_FOR_VM_CREATION, g_param_spec_boolean ("need-user-input-for-vm-creation", "need-user-input-for-vm-creation", "need-user-input-for-vm-creation", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_READY_TO_CREATE, g_param_spec_boolean ("ready-to-create", "ready-to-create", "ready-to-create", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_SUPPORTS_VIRTIO_DISK, g_param_spec_boolean ("supports-virtio-disk", "supports-virtio-disk", "supports-virtio-disk", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_SUPPORTS_VIRTIO_NET, g_param_spec_boolean ("supports-virtio-net", "supports-virtio-net", "supports-virtio-net", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_LIVE, g_param_spec_boolean ("live", "live", "live", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_INSTALLER_MEDIA_ARCHITECTURE, g_param_spec_string ("architecture", "architecture", "architecture", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	g_signal_new ("user_wants_to_create", BOXES_TYPE_INSTALLER_MEDIA, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3585 "installer-media.c"
}


static void boxes_installer_media_instance_init (BoxesInstallerMedia * self) {
}


static void boxes_installer_media_finalize (GObject* obj) {
	BoxesInstallerMedia * self;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (self->os);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (self->resources);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_object_unref0 (self->os_media);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (self->label);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (self->device_file);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	_g_free0 (self->mount_point);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	G_OBJECT_CLASS (boxes_installer_media_parent_class)->finalize (obj);
#line 3611 "installer-media.c"
}


GType boxes_installer_media_get_type (void) {
	static volatile gsize boxes_installer_media_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_installer_media_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesInstallerMediaClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_installer_media_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesInstallerMedia), 0, (GInstanceInitFunc) boxes_installer_media_instance_init, NULL };
		GType boxes_installer_media_type_id;
		boxes_installer_media_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesInstallerMedia", &g_define_type_info, 0);
		g_once_init_leave (&boxes_installer_media_type_id__volatile, boxes_installer_media_type_id);
	}
	return boxes_installer_media_type_id__volatile;
}


static void _vala_boxes_installer_media_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesInstallerMedia * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
	switch (property_id) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_SUPPORTED_DEVICES:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_take_object (value, boxes_installer_media_get_supported_devices (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_INSTALLED_SIZE:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_set_uint64 (value, boxes_installer_media_get_installed_size (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_NEED_USER_INPUT_FOR_VM_CREATION:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_set_boolean (value, boxes_installer_media_get_need_user_input_for_vm_creation (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_READY_TO_CREATE:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_set_boolean (value, boxes_installer_media_get_ready_to_create (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_SUPPORTS_VIRTIO_DISK:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_set_boolean (value, boxes_installer_media_get_supports_virtio_disk (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_SUPPORTS_VIRTIO_NET:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_set_boolean (value, boxes_installer_media_get_supports_virtio_net (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_LIVE:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_set_boolean (value, boxes_installer_media_get_live (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		case BOXES_INSTALLER_MEDIA_ARCHITECTURE:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		g_value_take_string (value, boxes_installer_media_get_architecture (self));
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 3680 "installer-media.c"
		default:
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/installer-media.vala"
		break;
#line 3686 "installer-media.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



